@@ -7,7 +7,7 @@ import gc
 import FUNC
 
 from multiprocessing import Pool
-def makeA(data_ord:pandas.DataFrame,Sparse=False):
+def makeA(data_ord:pd.DataFrame,Sparse=False):
     '''Calculate the additive kinship matrix using pedigree.
 
     data_ord: a dataframe of pedigree after sort.
